@@ -45,7 +45,7 @@ class RComboBoxPriv;
 class LIBKDCRAW_EXPORT RComboBox : public TQHBox
 {
 
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
