@@ -24,6 +24,10 @@
 #ifndef _LIBRAW_CLASS_H
 #define _LIBRAW_CLASS_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <limits.h>
 #include <memory.h>
 #include <stdio.h>
